@@ -184,7 +184,12 @@ Ambitus_engraver::finalize ()
 ADD_ACKNOWLEDGER (Ambitus_engraver, note_head);
 ADD_TRANSLATOR (Ambitus_engraver,
 		/* doc */ "",
-		/* create */ "Ambitus AmbitusLine AmbitusNoteHead AmbitusAccidental",
+		/* create */
+		"Ambitus "
+		"AmbitusLine "
+		"AmbitusNoteHead "
+		"AmbitusAccidental",
+
 		/* accept */ "",
 		/* read */ "",
 		/* write */ "");
