@@ -110,9 +110,9 @@ LY_DEFINE (ly_parse_file, "ly:parse-file",
       exit (2);
     }
 
-  if ((file_name != "-") && global_path.find (file_name).empty ())
+  if ((file_name != "-") && file_name.empty ())
     {
-      warning (_f ("can't find file: `%s'", file_name));
+      warning (_f ("can't find file: `%s'", file));
       scm_throw (ly_symbol2scm ("ly-file-failed"),
 		 scm_list_1 (scm_makfrom0str (file_name.c_str ())));
     }
