@@ -2,7 +2,7 @@
 ;;;;
 ;;;;  source file of the GNU LilyPond music typesetter
 ;;;; 
-;;;; (c) 2003--2006 Han-Wen Nienhuys <hanwen@cs.uu.nl>
+;;;; (c) 2003--2006 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
 (define-public (stack-stencils axis dir padding stils)
   "Stack stencils STILS in direction AXIS, DIR, using PADDING."
@@ -310,14 +310,6 @@ grestore
 	      rest))
 	expr))
   
-  (define (event-cause grob)
-    (let*
-	((cause (ly:grob-property  grob 'cause)))
-      
-      (cond
-       ((ly:stream-event? cause) cause)
-       ((ly:grob? cause) (event-cause cause))
-       (else #f))))
 
   (define (pythonic-string expr)
     "escape quotes and slashes for python consumption"
